@@ -32,3 +32,6 @@ CAPTCHA_TEST_MODE = False
 if CAPTCHA_DICTIONARY_MIN_LENGTH > CAPTCHA_DICTIONARY_MAX_LENGTH:
     CAPTCHA_DICTIONARY_MIN_LENGTH, CAPTCHA_DICTIONARY_MAX_LENGTH = CAPTCHA_DICTIONARY_MAX_LENGTH, CAPTCHA_DICTIONARY_MIN_LENGTH
 
+CAPTCHA_PREGEN = True
+CAPTCHA_PREGEN_PATH = '/tmp/flask-captcha'
+CAPTCHA_PREGEN_MAX = 10
\ No newline at end of file
